from setuptools import setup

setup(name='cl_file',
      version='0.1',
      description='Класс для работы с файлами',
      packages=['cl_file'],
      author_email='maleksa1296@gmail.com',
      zip_safe=False)